--****h* Installation/install.sql
-- NAME
--   sql/install.sql
-- AUTOR
--   Uwe Schied
-- COPYRIGHT
--   GPL
-- HISTORIE
--   28.05.2007 Steuerabrechnung eingefuegt
--              * tax
--              * tax_base
--              * tax_konten
--   20.08.2007 kurztext in ergaenzt
--   20.08.2007 bu_nr in tax ergaenzt
--   04.10.2008 Feature-Request 1293970 (optionale Felder) eingetragen
--              * opt_tabledef
--              * opt_tabledata
--   22.01.2009 Jahr in bu_konten ergaenzt
--   13.04.2009 komplett ueberarbeitet
--   03.11.2012 Feature-Request 3054813 offene Ueberweisungen verwalten
--   15.12.2013 Versionsverwaltung in die Datenbank integriert
--   27.12.2013 Mitgliederverwaltung angepasst
--   31.05.2014 Script für die variable Verwendung (neu und Update) vorbereitet
-- BUGS
--   Keine bekannt
--****

--
-- Datenbank-User festlegen
--
\set datenbankuser '''###DATENBANKUSER###'''

--****I* install.sql/key_anrede
-- INFO
--   Die Tabelle enthaelt die Anredeschluessel
-- SOURCE
CREATE TABLE IF NOT EXISTS key_anrede (
 schluessel SMALLINT PRIMARY KEY,
 brief      TEXT NOT NULL,
 inhalt     TEXT NOT NULL
);
-- BESCHREIBUNG
--   schluessel  auf diesen Wert wird referenziert
--   brief       Anrede fuer den Brief - z.B. Herr
--   inhalt      Anrede im Brief - z.B. Sehr geehrter Herr
--****
ALTER TABLE key_anrede OWNER TO :datenbankuser;

--****I* install.sql/key_zahlungsarten
-- INFO
--   Die Tabelle enthaelt die Zahlungsarten fuer alle Vereine
-- SOURCE
CREATE TABLE IF NOT EXISTS key_zahlungsarten (
 nr          SMALLINT PRIMARY KEY,
 bezeichnung TEXT NOT NULL
);
-- BESCHREIBUNG
--   nr           auf diesen Wert wird referenziert
--   bezeichnung  Beschreibung der Zahlungsart - z.B. per Rechnung
--****
ALTER TABLE key_zahlungsarten OWNER TO :datenbankuser;

--****I* install.sql/key_banken
-- INFO
--   Diese Tabelle enthaelt Bankleitzahlen und Banknamen. Die Angaben aus
--   der Tabelle werden fuer die Tabellen "vereine" und "*_einzug" benoetigt.
-- SOURCE
CREATE TABLE IF NOT EXISTS key_banken (
 blz  NUMERIC(8,0) NOT NULL PRIMARY KEY,
 bank TEXT NOT NULL
);
-- BESCHREIBUNG
--   blz  Bankleitzahl
--   bank Name der Bank
--****
ALTER TABLE key_banken OWNER TO :datenbankuser;

--****I* install.sql/personen
-- INFO
--   Diese Tabelle enthaelt alle vereinsuebergreifenden Angaben zu den
--   einzelnen Mitgliedern
-- SOURCE
CREATE TABLE IF NOT EXISTS personen (
 nr         SERIAL UNIQUE,
 anrede     SMALLINT DEFAULT 1 NOT NULL,
 titel      TEXT,
 name       TEXT NOT NULL,
 vorname    TEXT NOT NULL,
 geboren    DATE DEFAULT '1800-01-01' NOT NULL,
 strasse    TEXT,
 hausnr     TEXT,
 land       VARCHAR(40),
 plz        NUMERIC(5,0),
 ort        TEXT,
 telefon    TEXT,
 email      TEXT
);
-- BESCHREIBUNG
--   nr         Personen-Nr. = Mitglieds-Nr.
--   anrede     Anrede - Referenz auf key_anrede
--   titel      Akademischer Titel
--   name       Nachname
--   vorname    Vorname
--   geboren    Geburtsdatum (unbekannt = 01.01.1800)
--   strasse    Strasse
--   hausnr     Hausnummer
--   land       Land
--   plz        Postleitzahl
--   ort        Ort
--   telefon    Telefon-Nr.
--   email      EMail-Adresse
--****
ALTER TABLE personen OWNER TO :datenbankuser;
CREATE UNIQUE INDEX personen_idx ON personen (name,vorname,geboren,plz,ort,email);

--****I* install.sql/vereine
-- INFO
--   Diese Tabelle enthaelt Angaben zu den vorhandenen Vereinen
-- SOURCE
CREATE TABLE IF NOT EXISTS vereine (
 name       TEXT NOT NULL,
 kurzname   VARCHAR(20) NOT NULL UNIQUE PRIMARY KEY,
 strasse    TEXT,
 ort        TEXT,
 blz        VARCHAR(10),
 bank       TEXT,
 kontonr    NUMERIC(15,0),
 iban       TEXT,
 bic        TEXT,
 identnr    TEXT,
 email      TEXT,
 version    TEXT DEFAULT '0.2.0'
);
-- BESCHREIBUNG
--   name       Vereinsname
--   kurzname   Eindeutiger Name des Vereins, auf den referenziert wird
--   strasse    Strasse des Vereins
--   ort        Ort des Vereins
--   blz        Bankleitzahl des Vereinskontos
--   bank       Bankbezeichnung des Vereinskontos
--   kontonr    Konto-Nr. des Vereins fuer die Beitragszahlungen
--   iban       IBAN
--   bic        SWIFT-BIC - wird voraussichtlich bis 2/2014 benoetigt
--   identnr    Glaeubiger-Identifikationsnr fuer die SEPA-Lastschrift
--   email      Mail-Adresse des Vereins
--   version    Versions-Nr. des Projekts - wird fuer Anpassungen benoetigt
--****
ALTER TABLE vereine OWNER TO :datenbankuser;

--****I* install.sql/bu_klassen
-- INFO
--   Diese Tabelle enthaelt die einzelnen Bereiche, in die die Konten aufge-
--   teilt werden
-- SOURCE
CREATE TABLE IF NOT EXISTS bu_klassen (
 verein      VARCHAR(20) NOT NULL REFERENCES vereine (kurzname),
 kl_nr       NUMERIC(10,0) NOT NULL,
 kl_name     TEXT
);
-- BESCHREIBUNG
--   verein      betroffener Verein
--   kl_nr       Nummer des Bereichs - auf diesen Wert wird referenziert
--   kl_name     Beschreibung des Bereichs.
--               z.B: - Ideeler Bereich
--                    - Zweckbetrieb
--                    - Finanzkonten
--****
ALTER TABLE bu_klassen OWNER TO :datenbankuser;
CREATE UNIQUE INDEX idx_bu_klassen ON bu_klassen (kl_nr,verein);

--****I* install.sql/bu_konten
-- INFO
--   Diese Tabelle enthaelt die Buchungskonten
-- SOURCE
CREATE TABLE IF NOT EXISTS bu_konten (
 verein       VARCHAR(20) NOT NULL REFERENCES vereine (kurzname),
 kto_nr       NUMERIC(10,0) NOT NULL,
 kto_name     TEXT NOT NULL,
 kto_klasse   NUMERIC(10,0) NOT NULL,
 kto_ziel     NUMERIC(10,0) NOT NULL,
 kto_stand    NUMERIC(25,2),
 jahr         VARCHAR(10)   NOT NULL DEFAULT EXTRACT(YEAR FROM CURRENT_DATE)
);
-- BESCHREIBUNG
--   verein       betroffener Verein
--   kto_nr       Konto-Nr.
--   kto_name     Beschreibung des Kontos
--   kto_klasse   Kontenbereich - siehe bu_klassen
--   kto_ziel     Auf welches Konto wird dieses Konto abgeschlossen? Wenn
--                kto_ziel und kto_nr identisch sind erfolgt der Abschluss
--                in der Gewinn- und Verlustrechung, ansonsten handelt es
--                sich um ein Unterkonto von kto_ziel
--   kto_stand    Kontostand (wird z.Zt. nicht gepflegt)
--   jahr         Buchungsjahr
--****
ALTER TABLE bu_konten OWNER TO :datenbankuser;
CREATE UNIQUE INDEX idx_bu_konten ON bu_konten (verein,jahr,kto_nr);

--****I* install.sql/bu_kst
-- INFO
--   Diese Tabelle enthaelt die Kostenstellen
-- SOURCE
CREATE TABLE IF NOT EXISTS bu_kst (
 verein       VARCHAR(20) NOT NULL REFERENCES vereine (kurzname),
 kst          NUMERIC(10,0) NOT NULL,
 kst_name     TEXT DEFAULT '+' NOT NULL
);
-- BESCHREIBUNG
--   verein       betroffener Verein
--   kst          Nr. der Kostenstelle
--   kst_name     Beschreibung der Kostenstelle
--****
ALTER TABLE bu_kst OWNER TO :datenbankuser;
CREATE  UNIQUE INDEX idx_bu_kst ON bu_kst (kst, verein);

--****I* install.sql/bu_belege
-- INFO
--   Diese Tabelle enthaelt die Buchungsbelege fuer alle Vereine
-- SOURCE
CREATE TABLE IF NOT EXISTS bu_belege (
 idx          SERIAL,
 b_verein     VARCHAR(20) NOT NULL REFERENCES vereine(kurzname),
 b_nr         NUMERIC(10,0) NOT NULL DEFAULT 0,
 b_jahr	      VARCHAR(10) NOT NULL DEFAULT EXTRACT(YEAR FROM CURRENT_DATE),
 b_datum      DATE DEFAULT current_date NOT NULL,
 b_konto      NUMERIC(10,0) NOT NULL,
 f_konto      NUMERIC(10,0) NOT NULL,
 b_betrag     NUMERIC(20,2) NOT NULL,
 b_steuer     NUMERIC(20,2),
 b_text       TEXT,
 b_kst        NUMERIC(10,0) NOT NULL,
 erledigt     BOOLEAN NOT NULL DEFAULT FALSE
);
-- BESCHREIBUNG
--   b_verein     betroffener Verein
--   b_nr         Buchungs-Nr. (ACHTUNG: Nr. 1 ist fuer den Uebertrag reserviert
--                und wird beim Jahreswechsel ueberschrieben)
--   b_jahr	  Buchungsjahr
--   b_datum      Buchungsdatum
--   b_konto      Buchungskonto
--   f_konto      Finanzkonto
--   b_betrag     Buchungsbetrag (brutto)
--   b_steuer     Im Buchungsbetrag enthaltene Vorsteuer
--   b_text       Buchungstext
--   b_kst        Kostenstelle
--   erledigt     Kennzeichnung fuer offene Ueberweisungen
--                TRUE  = erledigt
--                FALSE = Ueberweisung ist offen
--****
ALTER TABLE bu_belege OWNER TO :datenbankuser;
CREATE UNIQUE INDEX bu_belege_idx ON bu_belege (idx);

--****I* install.sql/bilanz
-- INFO
--   Informationen zur Gewinn- und Verlustrechnung
-- SOURCE
CREATE TABLE IF NOT EXISTS bilanz (
 verein     VARCHAR(20) NOT NULL REFERENCES vereine(kurzname),
 jahr	    VARCHAR(10) NOT NULL DEFAULT EXTRACT(YEAR FROM CURRENT_DATE),
 summe      NUMERIC(30,0) NOT NULL,
 waehrung   VARCHAR(10) NOT NULL DEFAULT 'EUR',
 schlusstxt TEXT,
 prueftxt   TEXT,
 datum      DATE NOT NULL DEFAULT CURRENT_DATE
);
-- BESCHREIBUNG
--   verein     betroffener Verein
--   jahr	Buchungsjahr
--   summe      Endsumme der Gewinn- und Verlustrechnung = Uebertrag ins
--              naechste Buchungsjahr
--   waehrung   Waehrung, in der gebucht wird -> Voreinstellung = EUR
--   schlusstxt Schlusstext, der auf der Gewinn- und Verlustrechnung direkt nach
--              den Ergebnissen aufgedruckt wird
--   prueftxt   Informationstext zur Pruefung der Gewinn- und Verlustrechnung
--   datum      Datum, an dem die Buchungen geprueft wurden
--****
ALTER TABLE bilanz OWNER TO :datenbankuser;
CREATE UNIQUE INDEX idx_bilanz ON bilanz (verein,jahr);

--****I* install.sql/beitrag
-- INFO
--   In diese Tabelle werden die Beitragsbuchungen eingetragen
-- SOURCE
CREATE TABLE IF NOT EXISTS beitrag (
 bu_nr      SERIAL,
 v_name     VARCHAR(20) NOT NULL REFERENCES vereine(kurzname),
 m_nr       INTEGER NOT NULL REFERENCES personen(nr),
 jahr	    VARCHAR(10) NOT NULL DEFAULT EXTRACT(YEAR FROM CURRENT_DATE),
 f_konto    NUMERIC(10,0) NOT NULL DEFAULT '0',
 datum      DATE DEFAULT current_date,
 soll       NUMERIC(30,2) DEFAULT '0.00',
 haben      NUMERIC(30,2) DEFAULT '0.00',
 bu_text    TEXT
);
-- BESCHREIBUNG
--   v_name     betroffener Verein
--   m_nr       Mitglieds-Nr.
--   jahr	Buchungsjahr
--   f_konto    Finanzkonto
--   datum      Buchungsdatum
--   soll       Sollbuchung - fliesst nicht in die Finanzbuchhaltung
--   haben      Habenbuchung - fliesst in die Finanzbuchhaltung
--   bu_text    Freier Erlaeuterungstext
--****
ALTER TABLE beitrag OWNER TO :datenbankuser;
CREATE UNIQUE INDEX beitrag_idx ON beitrag (bu_nr);

--****I* install.sql/beitrags_art
-- INFO
--   Die Tabelle enthaelt die Beitragsarten des Vereins. Z.B.
--     * Ehrenmitglied
--     * passives Mitglied
--     * Mitgliedsbeitrag
-- SOURCE
CREATE TABLE IF NOT EXISTS beitrags_art (
 nr            SERIAL,
 verein        VARCHAR(20) NOT NULL REFERENCES vereine (kurzname),
 art           TEXT,
 jahresbeitrag NUMERIC(30,2) DEFAULT '0.00'
);
-- BESCHREIBUNG
--   nr            Nummer fuer die Beitragsart - wird automatisch vergeben
--   verein        Fuer welchen Verein gilt die Beitragsart
--   art           Beschreibung der Beitragsart, die in der Mitgliederverwaltung
--                 angegeben wird
--   jahresbeitrag Jahresbeitrag
--****
ALTER TABLE beitrags_art OWNER TO :datenbankuser;
CREATE UNIQUE INDEX beitrags_art_idx ON beitrags_art (nr);


--****I* install.sql/zahlungsweise
-- INFO
--   Diese Tabelle enthaelt Informationen ueber die definierten Zahlungsweisen.
--   Auf diese Tabelle referenzieren die fuer die Beitragszahlung zustaendigen
--   Tabellen.
-- SOURCE
CREATE TABLE IF NOT EXISTS zahlungsweise (
 nr       INTEGER NOT NULL UNIQUE,
 art      TEXT,
 einmalig BOOLEAN DEFAULT false NOT NULL,
 teiler   INTEGER DEFAULT 1 NOT NULL
);
-- BESCHREIBUNG
--   nr       Schluessel, auf den referenziert wird
--   art      Bezeichnung im Klartext
--   einmalig Einmalzahlung (ja/nein)
--   teiler   Teiler fuer den Jahresbeitrag
-- BESTANDTEILE
--   nr  art              einmalig teiler
--   -------------------------------------
--    0  einmalig         ja            1
--    1  jaehrlich        nein          1
--    2  halbjaehrlich    nein          2
--    3  monatlich        nein         12
--    4  vierteljaehrlich nein          4
--****
ALTER TABLE zahlungsweise OWNER TO :datenbankuser;
CREATE UNIQUE INDEX zahlungsweise_idx ON zahlungsweise (nr);

--****I* install.sql/beitrags_konto
-- INFO
--   Die Tabelle enthaelt Angaben zu Beitragsfaelligkeiten
-- SOURCE
CREATE TABLE IF NOT EXISTS beitrags_konto (
 nr            SERIAL,
 v_name        VARCHAR(20) NOT NULL REFERENCES vereine (kurzname),
 m_nr          INTEGER NOT NULL REFERENCES personen (nr),
 faellig_ab    DATE DEFAULT current_date,
 art           INTEGER NOT NULL REFERENCES beitrags_art (nr),
 zahlungsweise INTEGER NOT NULL REFERENCES zahlungsweise (nr)
);
-- BESCHREIBUNG
--   nr            Fortlaufende Nr. - dient als eindeutiger Identifizierer
--   v_name        betroffener Verein
--   m_nr          Mitglieds-Nr
--   faellig_ab    1. Faelligkeitsdatum
--   art           Beitragsart
--   zahlungsweise Zahlungsweise
--****
ALTER TABLE beitrags_konto OWNER TO :datenbankuser;
CREATE UNIQUE INDEX beitrags_konto_idx ON beitrags_konto (nr);

--****I* install.sql/virtual_konto
-- INFO
--   Diese Tabelle enthaelt Informationen ueber vereinsintern benoetigte Werte
--   und Zuordnungen. Sie wird von verschiedenen Programmteilen benoetigt um
--   Werte korrekt zuordnen zu koennen.
-- SOURCE
CREATE TABLE IF NOT EXISTS virtual_konto (
 verein       VARCHAR(20) NOT NULL REFERENCES vereine(kurzname),
 art          VARCHAR(20) NOT NULL,
 konto        NUMERIC(10,0) NOT NULL,
 fkonto       NUMERIC(10,0) NOT NULL,
 kst          NUMERIC(10,0) NOT NULL
);
ALTER TABLE virtual_konto OWNER TO :datenbankuser;
-- BESCHREIBUNG
--   verein        betroffener Verein
--   art           Schluessel ueber den zugegriffen wird. Je nach Schluessel
--                 enhalten die Felder konto, fkonto und kst die gesuchten
--                 Werte. Folgende Zuordnungen sind vorhanden:
--                    Bedeutung des Schluessels / Inhalt
--     art            Feld    Was steht im Feld?
--     ------------------------------------------------------------------------
--     BEITRAG        Zuordnung der Beitragszahlungen aus der Mitglieder-
--                    verwaltung zu den Buchhaltungskonten
--                    konto   Beitragskonto fuer die Buchhaltung
--                    fkonto  Finanzkonto, das als Voreinstellung in der
--                            Mitgliederverwaltung eingetragen wird
--                    kst     Kostenstelle fuer die Beitragsbuchungen
--     BEITRAG_1      1. Beitragserinnerung
--                    konto   Nummer des zu Briefes - siehe "briefe"
--                    fkonto  Hoehe der anfallenden Mahnkosten
--     BEITRAG_2      2. Beitragserinnerung
--                    konto   Nummer des zu Briefes - siehe "briefe"
--                    fkonto  Hoehe der anfallenden Mahnkosten
--     BEITRAG_3      Letzte Mahnung
--                    konto   Nummer des zu Briefes - siehe "briefe"
--                    fkonto  Hoehe der anfallenden Mahnkosten
--     BEITRAG_LEV    Brief nach einer Lastschrift-Retoure
--                    konto   Nummer des zu Briefes - siehe "briefe"
--                    fkonto  Hoehe der anfallenden Mahnkosten
--     FINANZKONTO    Welcher Kontenart gehoeren die Finanzkonten an?
--                    konto   Kontenart der Finanzkonten - siehe "bu_klassen"
--     SCHWEBEKONTO   Welches Konto wird als Schwebekonto verwandt?
--                    konto   Konto-Nr. - siehe "bu_konten"
--     UEBERTRAG      Zuordnung des Uebertrags bei Jahreswechsel
--                    konto   Kontenart - siehe "bu_klassen"
--                    fkonto  Konto-Nr. - siehe "bu_konten"
--                    kst     Kostenstelle - siehe "bu_kst"
--     VORSTEUER      Wie wird die in bu_belege.b_steuer eingetragene Vorsteuer
--                    in die Buchhaltung eingetragen?
--                    konto   Buchungskonto - siehe "bu_konten"
--                    fkonto  Finanzkonto - siehe "bu_konten"
--                    kst     Kostenstelle - siehe "bu_kst"
--****
CREATE UNIQUE INDEX virtual_konto_index ON virtual_konto (verein,art);

--****I* install.sql/briefe
-- INFO
--   Brieftexte fuer verschiedene Anlaesse
-- SOURCE
CREATE TABLE IF NOT EXISTS briefe (
 verein       VARCHAR(20) NOT NULL REFERENCES vereine(kurzname),
 nr           INT4,
 info         VARCHAR(40) NOT NULL,
 inhalt       TEXT
);
-- BESCHREIBUNG
--   verein       betroffener Verein
--   nr           Brief-Nr - auf dieses Feld wird referenziert
--   info         Kurzbeschreibung des Briefes
--   inhalt       Brieftext incl. Platzhaltern. Die folgenden Platzhalter sind
--                definiert:
--                %%BEITRAG%%      stellt eine Tabelle in den Brief mit allen
--                                 Beitragsbuchungen incl. Buchungstext
--                %%TERMIN28%%     wird im Brieftext durch das aktuelle Datum
--                                 + 28 Tage ersetzt
--****
ALTER TABLE briefe OWNER TO :datenbankuser;
CREATE  UNIQUE INDEX briefe_index ON briefe (nr, verein);

--****I* install.sql/tax
-- INFO
--   Diese Tabelle enthaelt Daten zur Umsatzsteuer-Erklaerung
-- SOURCE
CREATE TABLE IF NOT EXISTS tax (
  verein	VARCHAR(20)    NOT NULL REFERENCES vereine(kurzname),
  jahr		NUMERIC (10,0) NOT NULL DEFAULT EXTRACT (YEAR FROM CURRENT_DATE),
  datum		DATE           NOT NULL DEFAULT CURRENT_DATE,
  art		INT            NOT NULL,
  umsatz	NUMERIC (20,2),
  steuer	NUMERIC (20,2),
  bu_nr		NUMERIC (10,0) DEFAULT 0
);
-- BESCHREIBUNG
--   verein       betroffener Verein
--   jahr         Buchungsjahr
--   datum        Datum, an dem die Steuererklaerung bzw. Voranmeldung ans
--                Finanzamt gesandt oder elektronisch uebertragen wurde
--   art          Steuerart - siehe tax_base
--   umsatz       Netto-Umsatz
--   steuer       Steuer-Betrag
--   bu_nr        Buchungs-Nr. unter der die Steuerabrechnung in der Buchhaltung
--                eingetragen ist. 0 = noch nicht eingetragen
--****
ALTER TABLE tax OWNER TO :datenbankuser;
CREATE UNIQUE INDEX tax_index ON tax (verein,jahr,datum,art);

--****I* install.sql/tax_base
-- INFO
--   Diese Tabelle enthaelt Informationen ueber die Steuer-Arten pro Verein
-- SOURCE
CREATE TABLE IF NOT EXISTS tax_base (
  verein	VARCHAR(20)	NOT NULL REFERENCES vereine(kurzname),
  nr		INT		NOT NULL DEFAULT 0,
  name		TEXT		NOT NULL,
  steuersatz	NUMERIC(8,4),
  rundung	INT		NOT NULL DEFAULT 2,
  kurztext	TEXT
);
-- BESCHREIBUNG
--   verein     betroffener Verein
--   nr         Nr. der Steuerart - auf dieses Feld verweisen
--                * tax.art
--                * tax_konten.steuersatz
--   name       Bezeichnung der Steuerart
--   steuersatz Steuersatz
--   rundung    Auf wieviele Stellen hinter dem Komma wird die Steuer gerundet?
--   kurztext   Hinweise - optionale Angaben
--****
ALTER TABLE tax_base OWNER TO :datenbankuser;
CREATE UNIQUE INDEX tax_base_idx ON tax_base (verein,nr);

--****I* install.sql/tax_konten
-- INFO
--   Diese Tabelle enthaelt die Zuordnung der Buchungskonten zu den einzelnen
--   Steuerarten
-- SOURCE
CREATE TABLE IF NOT EXISTS tax_konten (
  verein	VARCHAR(20)	NOT NULL REFERENCES vereine(kurzname),
  steuersatz	INT		NOT NULL,
  kto		NUMERIC(10,0)	NOT NULL
);
-- BESCHREIBUNG
--   verein     betroffener Verein
--   steuersatz Steuerart - siehe tax_base
--   kto        Konto-Nr., der die Steuerart zugeordnet wird
--****
ALTER TABLE tax_konten OWNER TO :datenbankuser;
CREATE UNIQUE INDEX tax_konten_idx ON tax_konten (verein,kto);

--****I* install.sql/opt_tabledef
-- INFO
--   Definitionstabelle fuer weitere Felder in der Mitgliederverwaltung
-- SOURCE
CREATE TABLE IF NOT EXISTS opt_tabledef (
  nr            SERIAL UNIQUE,
  verein	VARCHAR(20) NOT NULL REFERENCES vereine(kurzname),
  bezeichnung	VARCHAR(50) NOT NULL,
  beschreibung	TEXT
);
-- BESCHREIBUNG
--   nr            Eindeutiges Kennzeichen - existiert vereinsuebergreifend nur
--                 einmal in der Tabelle
--   verein	   betroffener Verein
--   bezeichnung   Kurzbezeichnung des Feldes (muss gefuellt werden)
--   beschreibung  Ausfuehrliche Beschreibung des Feldes (kann leer bleiben)
--****
ALTER TABLE opt_tabledef OWNER TO :datenbankuser;
CREATE UNIQUE INDEX opt_tabledef_idx ON opt_tabledef (verein,bezeichnung);

--****I* install.sql/opt_tabledata
-- INFO
--   Tabelle mit den Inhalten der optionalen Felder zur Mitgliederverwaltung
-- SOURCE
CREATE TABLE IF NOT EXISTS opt_tabledata (
  opt_table	BIGINT NOT NULL REFERENCES opt_tabledef (nr),
  person	BIGINT NOT NULL REFERENCES personen (nr),
  inhalt	TEXT
);
-- BESCHREIBUNG
--   opt_table  Welches optionales Feld? - Referenz auf "opt_tabledata"
--   person     Welches Mitglied? - Referenz auf "personen"
--   inhalt     Inhalt des optionalen Feldes
--****
ALTER TABLE opt_tabledata OWNER TO :datenbankuser;
CREATE UNIQUE INDEX opt_tabledata_idx ON opt_tabledata (opt_table,person);

--****I* install.sql/version
-- INFO
--   Versionsverwaltung - hier steht immer die aktuell installierte Version
-- SOURCE
CREATE TABLE IF NOT EXIStS version (
 version     INTEGER NOT NULL DEFAULT 0,
 subversion  INTEGER NOT NULL DEFAULT 0,
 release     INTEGER NOT NULL DEFAULT 0,
 revision    INTEGER NOT NULL DEFAULT 0,
 typ         TEXT    NOT NULL DEFAULT 'stable'
);
--****
ALTER TABLE version OWNER TO :datenbankuser;

--****I* install.sql/mitglied
-- INFO
--   Mitgliederverwaltung
-- SOURCE
 CREATE TABLE IF NOT EXISTS mitglied (
  verein       VARCHAR(20) NOT NULL REFERENCES vereine(kurzname),
  nr           INT8        NOT NULL REFERENCES personen(nr)           DEFAULT 1,
  eintritt     DATE        NOT NULL                                   DEFAULT CURRENT_DATE,
  ende         DATE,
  kommentar    TEXT,
  zahlungsart  SMALLINT    NOT NULL REFERENCES key_zahlungsarten(nr)  DEFAULT 1,
  bic          TEXT,
  iban         TEXT,
  bank         TEXT,
  unterschrift DATE        NOT NULL                                   DEFAULT CURRENT_DATE,
  lastschrift  INT8        NOT NULL                                   DEFAULT 0,
  aktiv        BOOLEAN                                                DEFAULT true
);
 ALTER TABLE mitglied OWNER TO :datenbankuser;
 CREATE UNIQUE INDEX mitglied_idx ON mitglied (verein,nr);
--****